@@ -152,6 +152,9 @@ proc j:tb:is_last_line { W } {
 
 # j:tb:key_bind W - set up bindings to process keys
 proc j:tb:key_bind { W args } {
+  # restore mouse pointer on motion:
+  bind $W <Any-Motion> {j:show_pointer %W}
+  
   # get rid of a few default Tk bindings:
   
   j:tk3 {
@@ -198,6 +201,7 @@ proc j:tb:key_bind { W args } {
       <Escape>
     } {
       bind $W $binding {
+        j:hide_pointer %W
         j:tkb:process_key %W "" %K %A
         break
       }
@@ -242,6 +246,7 @@ proc j:tb:key_bind { W args } {
       <Control-Key> <Control-Shift-Key>
     } {
       bind $W $binding {
+        j:hide_pointer %W
         j:tkb:process_key %W Control %K %A
         break
       }
@@ -273,9 +278,18 @@ proc j:tb:key_bind { W args } {
     bind $W $binding { }
   }
   j:tk3 {
-    bind $W <Key>		{j:tkb:process_key %W "" %K %A}
-    bind $W <Shift-Key>		{j:tkb:process_key %W "" %K %A}
-    bind $W <Control-Key>	{j:tkb:process_key %W Control %K %A}
+    bind $W <Key> {
+      j:hide_pointer %W
+      j:tkb:process_key %W "" %K %A
+    }
+    bind $W <Shift-Key> {
+      j:hide_pointer %W
+      j:tkb:process_key %W "" %K %A
+    }
+    bind $W <Control-Key> {
+      j:hide_pointer %W
+      j:tkb:process_key %W Control %K %A
+    }
   }
   
   # Compose (Multi_key) key support:
