@@ -10,6 +10,8 @@
 # your users with instructions for getting the original sources.     #
 ######################################################################
 
+catch {package require jldb}
+
 ######################################################################
 # j:command:register cmd ?name? - 
 #   register the existence of a command procedure
@@ -68,7 +70,7 @@ proc j:command:buttonbar {args} {
   }
 
   if {[llength $args] != 3} {
-    error [j:ldb:text misc:badargs {Improper arguments}]
+    error [::jldb::long_text misc:badargs {Improper arguments}]
   }
   
   set newframe [lindex $args 0]
