@@ -10,6 +10,12 @@
 # your users with instructions for getting the original sources.     #
 ######################################################################
 
+catch {
+  package require jldb
+  ::jldb::load_pkg				;# so namespace is defined
+  namespace import ::jldb::shortcuts::*
+}
+
 ##############################################################################
 # jdoc:cmd:about - make the about box
 ##############################################################################
@@ -17,7 +23,7 @@
 j:command:register jdoc:cmd:about {About the Doc Viewer...}
 proc jdoc:cmd:about { w args } {
   global JSTOOLS_VERSION
-  set about_jdoc [j:ldb rt:about_jdoc {
+  set about_jdoc [= rt:about_jdoc [format {
     j:rt:hl "jdoc"
     j:rt:cr
     j:rt:rm "by Jay Sekora, "
@@ -25,7 +31,7 @@ proc jdoc:cmd:about { w args } {
     j:rt:par
     j:rt:rm "An X Windows application for viewing help files."
     j:rt:cr
-    j:rt:rm "Version $JSTOOLS_VERSION."
+    j:rt:rm "Version %s."
     j:rt:par
     j:rt:rm "Copyright \251 1992-1995 by Jay Sekora.  "
     j:rt:rm "Terms for copying are specified in the documentation and "
@@ -36,12 +42,12 @@ proc jdoc:cmd:about { w args } {
     j:rt:rm "Feel free to use bits of this code in your own "
     j:rt:tt "wish"
     j:rt:rm " scripts."
-  }]
+  } $JSTOOLS_VERSION]]
   j:about .about $about_jdoc
-  j:about:button .about {jdoc} $about_jdoc
-  j:about:button .about {Author} [j:about_jay]
-  j:about:button .about {Tk and Tcl} [j:about_tktcl]
-  j:about:button .about {Donations} [j:about_donations]
+  j:about:button .about [- {jdoc}] $about_jdoc
+  j:about:button .about [- {Author}] [j:about_jay]
+  j:about:button .about [- {Tk and Tcl}] [j:about_tktcl]
+  j:about:button .about [- {Donations}] [j:about_donations]
   
   tkwait window .about
 }
@@ -250,3 +256,4 @@ proc jdoc:register_commands {} {}
 ######################################################################
 
 
+
