@@ -2,7 +2,7 @@
 #   (preference commands are in jedit_prefs.tcl)
 #
 ######################################################################
-# Copyright 1992-1995 by Jay Sekora.  This file may be freely        #
+# Copyright 1992-1997 by Jay Sekora.  This file may be freely        #
 # distributed, modified or unmodified, for any purpose, provided     #
 # that this copyright notice is retained verbatim in all copies and  #
 # no attempt is made to obscure the authorship of this file.  If you #
@@ -11,6 +11,12 @@
 # your users with instructions for getting the original sources.     #
 ######################################################################
 
+catch {
+  package require jldb
+  ::jldb::load_pkg				;# so namespace is defined
+  namespace import ::jldb::shortcuts::*
+}
+
 j:ldb:set_defaults {
   {JErt:about_jedit {
     j:rt:hl "jedit"
@@ -59,6 +65,54 @@ j:ldb:set_defaults {
   {JEbutton:done {Done}}
 }
 
+::jldb::set_defaults {
+  {JErt:about_jedit {
+    j:rt:hl "jedit"
+    j:rt:cr
+    j:rt:rm "by Jay Sekora, "
+    j:rt:tt "js@aq.org"
+    j:rt:par
+    j:rt:rm "A customisable text editor for X Windows."
+    j:rt:cr
+    j:rt:rm "Version $JSTOOLS_VERSION."
+    j:rt:par
+    j:rt:rm "Copyright \251 1992-1995 by Jay Sekora.  "
+    j:rt:rm "Terms for copying are specified in the documentation and "
+    j:rt:rm "in comments in the code."
+    j:rt:par
+    j:rt:rm "If you find bugs or have suggestions for improvement, "
+    j:rt:rm "please let me know.  "
+    j:rt:rm "Feel free to use bits of this code in your own "
+    j:rt:tt "wish"
+    j:rt:rm " scripts."
+  }}
+  
+  {JEabout:jedit {jedit}}
+  {JEabout:author {Author}}
+  {JEabout:tk+tcl {Tk and Tcl}}
+  {JEabout:donations {Donations}}
+  {JEprompt:mode {Editing Mode:}}
+  {JEconfirm:close_window {Are you sure you want to close this window?}}
+  {JEconfirm:quit {Are you sure you want to quit?}}
+  {JEprompt:load {Load:}}
+  {JEprompt:saveas {Save as:}}
+  {JEconfirm:...exists_replace {File "$filename" exists; replace it?}}
+  {JEconfirm:print_to... 
+    {Print using `lpr' to printer `$J_PREFS(printer)'?}}
+  {JEconfirm:print_ps_to... 
+    {Print as PostScript using `lpr' to printer `$J_PREFS(printer)'?}}
+  {JEprompt:insert {Insert:}}
+  {JEtitle:note {Note}}
+  {JEprompt:unix_filter {Unix filter:}}
+  {JEprompt:unix_cmd {Unix command:}}
+  {JEprompt:go_to_line {Go to line number:}}
+  {JEmsg:at_line...column...
+    {The insertion point is at line $line, column $column.}}
+  {JEtitle:characters {Characters}}
+  {JEmsg:click_on_char {Click on a character to insert it.}}
+  {JEbutton:done {Done}}
+}
+
 ######################################################################
 #
 # NOTE: these mostly take the arguments "t args", where t is the text
@@ -76,12 +130,12 @@ j:ldb:set_defaults {
 j:command:register jedit:cmd:about {About the Editor...}
 proc jedit:cmd:about { t args } {
   global JSTOOLS_VERSION
-  set about_editor [j:ldb JErt:about_jedit]
+  set about_editor [subst -nobackslashes -nocommands [= JErt:about_jedit]]
   j:about .about $about_editor
-  j:about:button .about JEabout:jedit $about_editor
-  j:about:button .about JEabout:author [j:about_jay]
-  j:about:button .about JEabout:tk+tcl [j:about_tktcl]
-  j:about:button .about JEabout:donations [j:about_donations]
+  j:about:button .about [- JEabout:jedit] $about_editor
+  j:about:button .about [- JEabout:author] [j:about_jay]
+  j:about:button .about [- JEabout:tk+tcl] [j:about_tktcl]
+  j:about:button .about [- JEabout:donations] [j:about_donations]
   
   tkwait window .about
 }
@@ -516,10 +570,11 @@ j:command:register jedit:cmd:edit_abbrevs {Edit Static Abbreviations}
 proc jedit:cmd:edit_abbrevs { args } {
   global HOME
   if {! [file isdirectory "$HOME/.tk"]} then {
-    exec mkdir "$HOME/.tk"
+    file mkdir [file join $HOME .tk]
     # above should have error-checking
   }
-  exec jabbrevs "$HOME/.tk/abbrevs.tcl" &	;# doesn't currently use arg
+  # following doesn't currently use arg
+  exec jabbrevs [file join $HOME .tk abbrevs.tcl] &
 }
 
 ######################################################################
@@ -747,12 +802,7 @@ proc jedit:cmd:char_panel { t args } {
     <Shift-Button-1> <B1-Motion> <Triple-Button-1> <Double-Button-1>
     <Button-1>
   } {
-    j:tk3 {
-      bind $tl.t $event {;}
-    }
-    j:tk4 {
-      bind $tl.t $event {break}
-    }
+    bind $tl.t $event {break}
   }
 }
 
@@ -873,6 +923,9 @@ j:command:register jedit:font:l_code {Code Listing}
 j:command:register jedit:font:l_samp {Sample Text}
 j:command:register jedit:format:background:clear {Plain Background}
 j:command:register jedit:format:foreground:clear {Plain Foreground}
+j:command:register jedit:format:list_item {List Item}
+j:command:register jedit:format:nest_list {Deeper List Level}
+j:command:register jedit:format:unnest_list {Shallower List Level}
 
 ######################################################################
 # dummy to force autoloading of this file (for registration of cmds):
