@@ -274,6 +274,10 @@ proc jedit:mkmenu:format {menu t} {
     -label [j:ldb:text JEmenu:characters] \
     -menu $menu.m.characters
   j:menu:commands $menu.m $t {
+    -
+    jedit:format:list_item
+    jedit:format:nest_list
+    jedit:format:unnest_list
     -
     jedit:cmd:rich_saveas
     -
