@@ -2,7 +2,7 @@
 #   (jedit:prefs:menus is in jedit_menus.tcl, for convenience.)
 #
 ######################################################################
-# Copyright 1992-1995 by Jay Sekora.  This file may be freely        #
+# Copyright 1992-1997 by Jay Sekora.  This file may be freely        #
 # distributed, modified or unmodified, for any purpose, provided     #
 # that this copyright notice is retained verbatim in all copies and  #
 # no attempt is made to obscure the authorship of this file.  If you #
@@ -160,8 +160,7 @@ proc jedit:cmd:edit_prefs { t args } {
   j:default_button $w.b.save $w
   focus $w
   tkwait window $w
-  j:tk3 {focus $old_focus}
-  j:tk4 {focus -force $old_focus}	;# can't figure out a better way...
+  focus -force $old_focus		;# can't figure out a better way...
 }
 
 ######################################################################
@@ -263,15 +262,9 @@ proc jedit:cmd:mode_prefs { t args } {
     .mode_prefs.size.he \
     .mode_prefs
 
-  j:tab_ring \
-    .mode_prefs.font.bot.e \
-    .mode_prefs.size.we \
-    .mode_prefs.size.he
-  
   bind .mode_prefs <Key-Tab> {focus .mode_prefs.font.bot.e}
   tkwait window .mode_prefs
-  j:tk3 {focus $old_focus}
-  j:tk4 {focus -force $old_focus}	;# can't figure out a better way...
+  focus -force $old_focus		;# can't figure out a better way...
 }
 
 proc jedit:prefs:buttonbar { w mode } {
@@ -373,7 +366,7 @@ proc jedit:prefs:font { w mode } {
     -command "set JEDIT_MODEPREFS($mode,textfont) {default}"
   button $w.top.choose \
     -text [j:ldb:text JEbutton:choose] \
-    -command "set JEDIT_MODEPREFS($mode,textfont) \[j:prompt_font\]"
+    -command "set JEDIT_MODEPREFS($mode,textfont) \[list \[j:prompt_font\]\]"
   
   frame $w.bot
   entry $w.bot.e -width 50 \
