@@ -222,7 +222,6 @@ proc jedit:jedit { args } {
     jedit:userhook $window
   }
   if {"x$file" != "x"} {
-    tkwait visibility $text		;# bug workaround for unpatched tk3.6
     jedit:read $file $text
     if [string length $line] {		;# specify a particular line to go to
       jedit:go_to_line $text $line
@@ -367,10 +366,8 @@ proc jedit:text_regsub { t regex subst } {
     set finalcr 1
   }
   
-  j:tk4 {
-    if [$t compare end == sel.last] {
-      $t tag remove sel end-1c
-    }
+  if [$t compare end == sel.last] {
+    $t tag remove sel end-1c
   }
   
   regsub -all -- $regex $text $subst result
@@ -414,10 +411,8 @@ proc jedit:pipe { t command } {
     append text "\n"
   }
   
-  j:tk4 {
-    if [$t compare end == sel.last] {
-      $t tag remove sel end-1c
-    }
+  if [$t compare end == sel.last] {
+    $t tag remove sel end-1c
   }
   
   if [catch { eval exec $command << [list $text] } result] {
