@@ -26,6 +26,7 @@ j:ldb:set_defaults {
   {mode:jhtml:body_link {Link Colour}}
   {mode:jhtml:body_vlink {Visited Link Colour}}
   {mode:jhtml:body_alink {Active Link Colour}}
+  {mode:jhtml:import {Import...} 0}
   
   {{(new file)} {(new file)}}
   {{Link Name} {Link Name}}
@@ -90,23 +91,6 @@ proc mode:jhtml:init { t } {
   $t tag configure jdoc:xref:link -underline 1
   $t tag configure jdoc:xref:manpage -underline 1
     
-  catch {
-    $t tag configure list:level:1 -lmargin1 9m -lmargin2 9m
-    $t tag configure list:level:2 -lmargin1 18m -lmargin2 18m
-    $t tag configure list:level:3 -lmargin1 27m -lmargin2 27m
-  }
-  
-  $t tag configure special:list_item:1 -font \
-    -*-symbol-*-*-*-*-*-120-*-*-*-*-*-*
-  $t tag configure special:list_item:2 -font \
-    -*-symbol-*-*-*-*-*-120-*-*-*-*-*-*
-  $t tag configure special:list_item:3 -font \
-    -*-symbol-*-*-*-*-*-120-*-*-*-*-*-*
-  catch {
-    $t tag configure special:list_item:1 -lmargin1 5m -lmargin2 5m
-    $t tag configure special:list_item:2 -lmargin1 14m -lmargin2 14m
-    $t tag configure special:list_item:3 -lmargin1 23m -lmargin2 23m
-  }
   $t tag configure special:html:literal -borderwidth 2 -relief sunken
   catch {
     $t tag configure special:html:literal \
@@ -116,22 +100,17 @@ proc mode:jhtml:init { t } {
     -font nil2 -background black
   
   # need to wait until normal font tags have been created for following:
-  after idle [list $t tag raise special:list_item:1]
-  after idle [list $t tag raise special:list_item:2]
-  after idle [list $t tag raise special:list_item:3]
   after idle [list $t tag raise special:hr:normal]
   after idle [list $t tag raise special:html:literal]
   
   # not marked in browsers, but marked here so you get visual feedback
   # when you create them:
-  $t tag configure list:level:1 -relief raised -borderwidth 1
-  $t tag lower list:level:1
-  $t tag configure list:level:2 -relief raised -borderwidth 2
-  $t tag lower list:level:2
-  $t tag configure list:level:3 -relief raised -borderwidth 3
-  $t tag lower list:level:3
-  $t tag configure jdoc:anchor:anchorname -bgstipple gray25 -background gray25
+  $t tag configure jdoc:anchor:anchorname -relief sunken -borderwidth 2
   $t tag lower jdoc:anchor:anchorname
+  $t tag configure jhtml:anchor:anchorname -relief sunken -borderwidth 2
+  $t tag lower jhtml:anchor:anchorname
+  
+  # (and list tags are set after loading a file or when invoking list commands)
 }
 
 ######################################################################
@@ -199,6 +178,7 @@ proc mode:jhtml:read { filename t } {
   if ![string match {} $body_bgcolor] {
     catch {$t configure -background $body_bgcolor}
   }
+  jedit:format:configure_all_list_tags $t
 }
 
 ######################################################################
@@ -329,8 +309,40 @@ proc mode:jhtml:mkx_anchor { t } {
 proc mode:jhtml:mkx_url { t } {
   set from [$t index sel.first]
   set to [$t index sel.last]
-  set link "[string trim [$t get $from $to]].html"
-  regsub -all -- {[ +-]} $link {_} link
+  set selection [string trim [$t get $from $to]]
+  switch -glob -- $selection {
+    *<*@*>* {
+      regsub -- {.*<([^@]*@[^>]*)>.*} $selection {mailto:\1} link
+    }
+    *.txt -		*.htm -		*.html -
+    *.zip -		*.gz -		*.tgz -
+    *.tar -		*.hqx -		*.gif -
+    *.jpg -		*.jpeg -	*.png -
+    *.snd -		*.wav -		*.au -
+    *.aiff -		*.ps -		*.eps -
+    *.pdf -		*.pdb -		*.prc -
+    *.TXT -		*.HTM -		*.HTML -
+    *.ZIP -		*.GZ -		*.TGZ -
+    *.TAR -		*.HQX -		*.GIF -
+    *.JPG -		*.JPEG -	*.PNG -
+    *.SND -		*.WAV -		*.AU -
+    *.AIFF -		*.PS -		*.EPS -
+    *.PDF -		*.PDB -		*.PRC -
+    mailto:* -
+    */ -
+    *://* {
+      set link $selection
+    }
+    *@* {
+      set link mailto:$selection "<>"
+    }
+    default {
+      set link $selection.html
+      set link "[string trim [$t get $from $to]].html"
+      regsub -all -- {[ +-]} $link {_} link
+    }
+  }
+  
   set link [j:prompt -file 1 -title "URL" -text "URL:" \
     -default $link -file 1 -history url]
   
@@ -529,6 +541,256 @@ proc mode:jhtml:body_alink { t args } {
   j:tag:set_metainfo $t body_alink $alink
 }
 
+######################################################################
+######################################################################
+### HTML IMPORT PROCEDURES
+######################################################################
+######################################################################
+
+######################################################################
+proc mode:jhtml:put_text { WIDGET text } {
+  regsub -all -nocase -- {&lbrace;} $text \{ text
+  regsub -all -nocase -- {&rbrace;} $text \} text
+  regsub -all -nocase -- {&bslash;} $text {\\} text
+  regsub -all -nocase -- {&lt;} $text {<} text
+  regsub -all -nocase -- {&gt;} $text {>} text
+  regsub -all -nocase -- {&amp;} $text {\&} text
+
+  j:tag:insert_string $WIDGET $text
+  $WIDGET see end
+  update
+}
+
+proc mode:jhtml:start_tag { WIDGET html_tag } {
+  switch -glob -- [string tolower $html_tag] {
+    {<i>} {
+      j:tag:set_tag $WIDGET richtext:font:italic
+    }
+    {<b>} {
+      j:tag:set_tag $WIDGET richtext:font:bold
+    }
+    {<tt>} {
+      j:tag:set_tag $WIDGET richtext:font:typewriter
+    }
+    {<em>} {
+      j:tag:set_tag $WIDGET richtext:font:l_em
+    }
+    {<cite>} {
+      j:tag:set_tag $WIDGET richtext:font:l_cite
+    }
+    {<var>} {
+      j:tag:set_tag $WIDGET richtext:font:l_var
+    }
+    {<dfn>} {
+      j:tag:set_tag $WIDGET richtext:font:l_dfn
+    }
+    {<strong>} {
+      j:tag:set_tag $WIDGET richtext:font:l_strong
+    }
+    {<kbd>} {
+      j:tag:set_tag $WIDGET richtext:font:l_kbd
+    }
+    {<code>} {
+      j:tag:set_tag $WIDGET richtext:font:l_code
+    }
+    {<samp>} {
+      j:tag:set_tag $WIDGET richtext:font:l_samp
+    }
+    {<p *>} -
+    {<p>} {
+      $WIDGET insert end "\n\n" richtext:font:roman
+    }
+    {<hr>} {
+      if {[$WIDGET compare insert != {insert linestart}]} {
+        j:tag:insert_string $WIDGET "\n"
+      }        
+      $WIDGET insert end "\n" {special:hr:normal richtext:font:roman}
+    }
+    {<h1>} {
+      if {[$WIDGET compare insert != {insert linestart}]} {
+        j:tag:insert_string $WIDGET "\n"
+      }        
+      j:tag:set_tag $WIDGET richtext:font:heading0
+    }
+    {<h2>} {
+      if {[$WIDGET compare insert != {insert linestart}]} {
+        j:tag:insert_string $WIDGET "\n"
+      }        
+      j:tag:set_tag $WIDGET richtext:font:heading1
+    }
+    {<h3>} {
+      if {[$WIDGET compare insert != {insert linestart}]} {
+        j:tag:insert_string $WIDGET "\n"
+      }        
+      j:tag:set_tag $WIDGET richtext:font:heading2
+    }
+    {<h4>} {
+      if {[$WIDGET compare insert != {insert linestart}]} {
+        j:tag:insert_string $WIDGET "\n"
+      }        
+      j:tag:set_tag $WIDGET richtext:font:heading3
+    }
+    {<h5>} {
+      if {[$WIDGET compare insert != {insert linestart}]} {
+        j:tag:insert_string $WIDGET "\n"
+      }        
+      j:tag:set_tag $WIDGET richtext:font:heading4
+    }
+    {<h6>} {
+      if {[$WIDGET compare insert != {insert linestart}]} {
+        j:tag:insert_string $WIDGET "\n"
+      }        
+      j:tag:set_tag $WIDGET richtext:font:heading5
+    }
+    {<br>} {
+      if {[$WIDGET compare insert != {insert linestart}]} {
+        j:tag:insert_string $WIDGET "\n"
+      }        
+    }
+    {</ol>} -
+    {<ul>} {
+      if {[$WIDGET compare insert != {insert linestart}]} {
+        j:tag:insert_string $WIDGET "\n"
+      }        
+      jedit:format:nest_list $WIDGET
+    }
+    {<li>} {
+      if {[$WIDGET compare insert != {insert linestart}]} {
+        j:tag:insert_string $WIDGET "\n"
+      }        
+      jedit:format:list_item $WIDGET
+    }
+    {<a *href=*} {
+      set link ""
+      regsub -nocase -all -- {.* href="([^">]*).*} $html_tag {\1} link
+      if {[string length $link]} {
+        j:tag:set_tag $WIDGET jdoc:xref:link
+        j:tag:set_tag $WIDGET jdoc:link:$link
+      }
+    }
+    {<a *name=*} {
+      set name ""
+      regsub -nocase -all -- {.* name="([^">]*).*} $html_tag {\1} name
+      if {[string length $name]} {
+        j:tag:set_tag $WIDGET jdoc:anchor:anchorname
+        j:tag:set_tag $WIDGET jdoc:anchorname:$name
+      }
+    }
+    {<a[^a-z]*} {
+      # some <a> tag I don't understand; ignore it
+    }
+    {<!doctype*>} -
+    {<html>} -
+    {<head>} -
+    {<body*>} {
+      # ignore these tags
+    }
+    default {
+      $WIDGET insert insert $html_tag {special:html:literal richtext:font:roman}
+    }
+  }
+}
+
+proc mode:jhtml:end_tag { WIDGET html_tag } {
+  switch -glob -- [string tolower $html_tag] {
+    {</i>} -
+    {</b>} -
+    {</tt>} -
+    {</em>} -
+    {</cite>} -
+    {</var>} -
+    {</dfn>} -
+    {</strong>} -
+    {</kbd>} -
+    {</code>} -
+    {</samp>} {
+      j:tag:set_tag $WIDGET richtext:font:roman
+    }
+    {</h[0-9]>} {
+      if {[$WIDGET compare insert != {insert linestart}]} {
+        j:tag:insert_string $WIDGET "\n"
+      }        
+      j:tag:set_tag $WIDGET richtext:font:roman
+    }
+    {</a>} {
+      j:tag:clear_tag $WIDGET *:xref:*
+      j:tag:clear_tag $WIDGET *:link:*
+      j:tag:clear_tag $WIDGET *:anchor:*
+      j:tag:clear_tag $WIDGET *:anchorname:*
+    }
+    {</ol>} -
+    {</ul>} {
+      if {[$WIDGET compare insert != {insert linestart}]} {
+        j:tag:insert_string $WIDGET "\n"
+      }        
+      jedit:format:unnest_list $WIDGET
+    }
+    {</p>} -
+    {</html>} -
+    {</head>} -
+    {</body>} {
+      # ignore these tags
+    }
+    default {
+      $WIDGET insert insert $html_tag {special:html:literal richtext:font:roman}
+    }
+  }
+}
+
+j:command:register mode:jhtml:import {}
+proc mode:jhtml:import {w args} {
+  global WIDGET
+  set WIDGET $w
+  j:tag:set_tags $w richtext:font:roman
+  
+  set file [j:fs]
+  set fd [open $file r]
+  set html [read $fd]
+  close $fd
+  
+  ######################################################################
+  # get rid of characters that might mess up Tcl list processing:
+  
+  set html [join [split $html "\n"] "&newline;"]
+  regsub -all \{ $html {\&lbrace;} html
+  regsub -all \} $html {\&rbrace;} html
+  regsub -all {\\} $html {\&bslash;} html
+  
+  # change newlines (in original HTML source) into spaces
+  regsub -all {(&newline;)+} $html { } html
+  
+  # fold sequences of whitespace into a single space character
+  regsub -all "\[\t \]\[\t \]+" $html { } html
+  
+  # eliminate whitespace around paragraphs, breaks, or rules
+  regsub -nocase -all " *<p> *" $html {<p>} html
+  regsub -nocase -all " *</p> *" $html {</p>} html
+  regsub -nocase -all " *<br> *" $html {<br>} html
+  regsub -nocase -all " *<hr> *" $html {<hr>} html
+  
+  # eliminate whitespace after opening tags and before closing tags
+  regsub -all {(<[^/][^>]*>) } $html {\1} html
+  regsub -all { (</[^>]*>)} $html {\1} html
+  
+  set html "mode:jhtml:put_text [list $w] {$html}"
+  
+  # convert opening tags into "mode:jhtml:start_tag $w <tag>" commands
+  regsub -all {<[^/<>][^<>]*>} $html \
+    "\}\nmode:jhtml:start_tag $w {&}\nmode:jhtml:put_text $w \{" html
+  # convert closing tags into "mode:jhtml:end_tag $w <tag>" commands
+  regsub -all {</[^<>]*>} $html \
+    "\}\nmode:jhtml:end_tag $w {&}\nmode:jhtml:put_text $w \{" html
+
+  # execute the sequence of commands we've just turned the HTML into
+  eval $html
+}
+
+######################################################################
+######################################################################
+### END HTML IMPORT PROCEDURES
+######################################################################
+######################################################################
+
 ######################################################################
 
 proc mode:jhtml:mkmenu1 { menu t } {
@@ -563,6 +825,8 @@ proc mode:jhtml:mkmenu1 { menu t } {
     mode:jhtml:body_link
     mode:jhtml:body_vlink
     mode:jhtml:body_alink
+    -
+    mode:jhtml:import
   }
   
   bind $t <Meta-Key-1> "jedit:font:heading1 $t"
@@ -571,7 +835,7 @@ proc mode:jhtml:mkmenu1 { menu t } {
   bind $t <Meta-Key-5> "mode:jhtml:show_tags $t"
   bind $t <Meta-Key-6> "mode:jhtml:mkx_anchor $t"
   bind $t <Meta-Key-7> "mode:jhtml:mkx_anchor_link $t"
-  bind $t <Meta-Key-8> "mode:jhtml:mkx_link $t"
+  bind $t <Meta-Key-8> "mode:jhtml:mkx_url $t"
   bind $t <Meta-Key-9> "mode:jhtml:mkx_manpage $t"
 }
 
