@@ -7,7 +7,7 @@ j:ldb:set_defaults {
     {SHORT-mode:mh:start_reply {Insert @}}
   {mode:mh:insert_sig {Append Signature}}
     {SHORT-mode:mh:insert_sig {Sign}}
-  {mode:mh:delete_sig {Remove Signature}}
+  {mode:mh:delete_sig {Delete Signature}}
     {SHORT-mode:mh:delete_sig {Unsign}}
   {mode:mh:whom {List Recipients} 0 <Meta-Key-7>}
     {SHORT-mode:mh:whom {Whom}}
@@ -54,6 +54,7 @@ proc mode:mh:init { t } {
     {menu,abbrev 1}
     {menu,filter 1}
     {menu,format 0}
+    {menu,font 0}
     {menu,display 0}
     {menu,mode1 1}
     {menu,mode2 1}
