@@ -168,10 +168,7 @@ proc j:find {args} {
   update idletasks
   wm deiconify .find
   tkwait window .find
-  j:tk3 {focus $old_focus}
-  j:tk4 {
-    catch {focus -force $old_focus}	;# can't figure out a better way...
-  }
+  catch {focus -force $old_focus}	;# can't figure out a better way...
 }
 
 ######################################################################
