@@ -62,10 +62,10 @@ proc j:fs { args } {
     {dirhistory fs_dirs}
   }
   
-  set prompt [uplevel 1 [list j:ldb $prompt]]
-  set fileprompt [uplevel 1 [list j:ldb $fileprompt]]
-  set title [uplevel 1 [list j:ldb $title]]
-  set typeprompt [uplevel 1 [list j:ldb $typeprompt]]
+  set prompt [j:ldb:text $prompt]
+  set fileprompt [j:ldb:text $fileprompt]
+  set title [j:ldb:text $title]
+  set typeprompt [j:ldb:text $typeprompt]
   
   set doing_filehistory [string length $filehistory]
   set doing_dirhistory [string length $dirhistory]
@@ -172,7 +172,7 @@ proc j:fs { args } {
   }
 
   frame .fs.b -width 200
-  button .fs.b.ok -width 8 -text [j:ldb OK] -command {
+  button .fs.b.ok -width 8 -text [j:ldb:text OK] -command {
     set file [.fs.file.e get]
     if [string length $file] {
       if {[string length $file] && [file isdirectory ./$file]} {
@@ -202,7 +202,7 @@ proc j:fs { args } {
       update
     }
   }
-  button .fs.b.gointo -width 8 -text [j:ldb fs:gointo "Go Into"] -command {
+  button .fs.b.gointo -width 8 -text [j:ldb:text fs:gointo "Go Into"] -command {
     set file [.fs.file.e get]
     if {!([string match /* $file] || [string match ~* $file])} {
       set file ./$file
@@ -216,24 +216,26 @@ proc j:fs { args } {
       j:alert -text "\"$file\" is not a directory."
     }
   }
-  button .fs.b.home -width 8 -text [j:ldb fs:home] -command {
+  button .fs.b.home -width 8 -text [j:ldb:text fs:home] -command {
     cd $env(HOME)
     .fs.cwd configure -text [pwd]
     j:fs:fill_list .fs.list.lb
   }
-  button .fs.b.root -width 8 -text [j:ldb fs:root] -command {
+  button .fs.b.root -width 8 -text [j:ldb:text fs:root] -command {
     cd /
     .fs.cwd configure -text [pwd]
     j:fs:fill_list .fs.list.lb
   }
-  button .fs.b.here -width 8 -text [j:ldb fs:here] -command {
+  button .fs.b.here -width 8 -text [j:ldb:text fs:here] -command {
     set j_fs(result) [pwd]
     destroy .fs
     update
   }
-  button .fs.b.mkdir -width 8 -text [j:ldb fs:mkdir] -command {
+  button .fs.b.mkdir -width 8 -text [j:ldb:text fs:mkdir] -command {
     set dirname \
-      [j:prompt -file 1 -text [j:ldb fs:dirprompt] -title [j:ldb title:newdir]]
+      [j:prompt -file 1 \
+      -text [j:ldb:text fs:dirprompt] \
+      -title [j:ldb:text title:newdir]]
     if {![string match "" $dirname]} {
       exec mkdir $dirname
       cd $dirname			;# cd into directory, refresh list
@@ -242,12 +244,12 @@ proc j:fs { args } {
       .fs.file.e delete 0 end		;# clear filename space
     }
   }
-  button .fs.b.cancel -width 8 -text [j:ldb Cancel] -command "
+  button .fs.b.cancel -width 8 -text [j:ldb:text Cancel] -command "
     set j_fs(result) $cancelvalue
     destroy .fs
     update
   "
-  checkbutton .fs.b.fast -text [j:ldb fs:fast] \
+  checkbutton .fs.b.fast -text [j:ldb:text fs:fast] \
     -variable J_PREFS(j_fs_fast)
 
   pack .fs.list.sb -side $J_PREFS(scrollbarside) -fill y
@@ -410,16 +412,3 @@ proc j:fs:fill_list {lb} {
     }
   }
 }
-
-
-
-
-
-
-
-
-
-
-
-
-
