@@ -10,6 +10,10 @@
 # your users with instructions for getting the original sources.     #
 ######################################################################
 
+catch {
+  package require jldb
+}
+
 ######################################################################
 # j:menu:menubutton mb menu key -
 #   create a menubutton with an appropriate label and underline
@@ -61,7 +65,7 @@ proc j:menu:checkbuttons { args } {
     {command {}}
   }
   if { [llength $args] != 2 } {
-    error [j:ldb:text misc:badargs]
+    error [::jldb::long_text misc:badargs]
   }
   
   set menu [lindex $args 0]
@@ -112,7 +116,7 @@ proc j:menu:radiobuttons { args } {
     {variable VAR}
   }
   if { [llength $args] != 2 } {
-    error [j:ldb:text misc:badargs]
+    error [::jldb::long_text misc:badargs]
   }
   
   set menu [lindex $args 0]
