@@ -1,7 +1,7 @@
 # jmetawidgets.tcl - compound pseudo-widgets that can be packed
 #
 ######################################################################
-# Copyright 1992-1995 by Jay Sekora.  This file may be freely        #
+# Copyright 1992-1997 by Jay Sekora.  This file may be freely        #
 # distributed, modified or unmodified, for any purpose, provided     #
 # that this copyright notice is retained verbatim in all copies and  #
 # no attempt is made to obscure the authorship of this file.  If you #
@@ -15,6 +15,10 @@
 ###   make metawidgets create a widget command like real widgets
 ###   make metawidgets understand `-configure'
 
+catch {
+  package require jldb
+}
+
 ######################################################################
 # metawidget options:
 #
@@ -50,7 +54,7 @@ proc j:buttonbar {args} {
   }
 
   if {[llength $args] != 1} {
-    error [j:ldb:text misc:badargs {Improper arguments}]
+    error [::jldb::text misc:badargs {Improper arguments}]
   }
   
   set newframe [lindex $args 0]
@@ -83,13 +87,11 @@ proc j:buttonbar {args} {
     
     set button $newframe.$name
     button $button -width $width -text $text -command $command
-    set border $newframe.border_$name
-    frame $border -relief flat -borderwidth 1
-    raise $button
-    pack $button -in $border -padx 2 -pady 2
-    pack $border -in $newframe -side $side -padx 2
+    pack $button -in $newframe -side $side
     if [string match $default $name] {
-      $border configure -relief sunken
+      $button configure -default active
+    } else {
+      $button configure -default normal
     }
   }
   return $newframe
