@@ -1,7 +1,7 @@
 # joptionbutton.tcl - one-of-many choice button with popup list
 #
 ######################################################################
-# Copyright 1992-1996 by Jay Sekora.  This file may be freely        #
+# Copyright 1992-1998 by Jay Sekora.  This file may be freely        #
 # distributed, modified or unmodified, for any purpose, provided     #
 # that this copyright notice is retained verbatim in all copies and  #
 # no attempt is made to obscure the authorship of this file.  If you #
@@ -10,6 +10,10 @@
 # your users with instructions for getting the original sources.     #
 ######################################################################
 
+catch {
+  package require jldb
+}
+
 ######################################################################
 # create a new option button.  -font and -width can adjust appearance.
 #   -list is not really optional.  -current can set current value.
@@ -92,8 +96,8 @@ proc j:option { w args } {
         return {}
       }
       default {
-        error [j:ldb optionbutton:invalidarg \
-          "Invalid argument $option to option widget command $tmp."]
+        error [subst [::jldb::long_text optionbutton:invalidarg \
+          {Invalid argument $option to option widget command $tmp.}]]
       }
     }
   } $w]
@@ -154,8 +158,8 @@ proc j:option:configure { w arglist } {
         return [${w}-orig configure -width]
       }
       default {
-        error [j:ldb optionbutton:unknownoption \
-          "Unknown option \"$option\""]
+        error [subst [::jldb::long_text optionbutton:unknownoption \
+          {Unknown option "$option"}]]
       }
     }
   }
@@ -164,8 +168,8 @@ proc j:option:configure { w arglist } {
     set option [lindex $arglist 0]
     set value [lindex $arglist 1]
     if {"x$value" == "x"} {
-      error [j:ldb optionbutton:novalue \
-        "No value given to option \"$option\"."]
+      error [subst [::jldb::long_text optionbutton:novalue \
+        {No value given to option "$option".}]]
     }
     
     set arglist [lreplace $arglist 0 1]	;# with nothing
@@ -191,8 +195,8 @@ proc j:option:configure { w arglist } {
         ${w}-orig configure -width $value
       }
       default {
-        error [j:ldb optionbutton:unknownoption \
-          "Unknown option \"$option\""]
+        error [subst [::jldb::long_text optionbutton:unknownoption \
+          {Unknown option "$option"}]]
       }
     }
   }
