@@ -221,16 +221,16 @@ proc j:write_prefs { args } {
   set file $file.tcl
   
   if {"x$directory" == "x"} then {
-    set directory $env(HOME)/.tk	;# NOTE: created if necessary!
+    set directory [file join $env(HOME) .tk]	;# NOTE: created if necessary!
   }
   
   # make sure that ~ is properly expanded
   regsub -- {^~/} $directory $env(HOME)/ directory
   
   if {! [file isdirectory $directory]} {;# make sure directory exists
-    exec mkdir -p $directory
+    file mkdir $directory
   }
-  set f [open $directory/$file {w}]
+  set f [open [file join $directory $file] {w}]
   
   if {"x$prefix" == "x"} {		;# just names with no comma
     foreach pref_name [lsort [array names $array]] {
