@@ -1,7 +1,7 @@
 # jprompts.tcl - various panels to ask the user for something
 #
 ######################################################################
-# Copyright 1992-1996 by Jay Sekora.  This file may be freely        #
+# Copyright 1992-1998 by Jay Sekora.  This file may be freely        #
 # distributed, modified or unmodified, for any purpose, provided     #
 # that this copyright notice is retained verbatim in all copies and  #
 # no attempt is made to obscure the authorship of this file.  If you #
@@ -11,7 +11,6 @@
 ######################################################################
 
 ### TO DO
-###   make a real j:prompt_font
 ###   eval tcl commands at the global level
 ###   checkbox to display output of unix or tcl command
 
@@ -102,22 +101,13 @@ proc j:prompt { args } {
   j:dialogue .pr			;# position in centre of screen
 
   if $file {
-    j:tk3 {
-      bind .pr.mid.e <Tab> {
-        set f [%W get]
-        %W delete 0 end
-        %W insert end [j:expand_filename $f]
-      }
-    }
-    j:tk4 {
-      bind .pr.mid.e <Tab> {
-        set f [%W get]
-        %W delete 0 end
-        %W insert end [j:expand_filename $f]
-        %W xview end
-        focus %W			;# work around Tk4 "all" binding
-        break
-      }
+    bind .pr.mid.e <Tab> {
+      set f [%W get]
+      %W delete 0 end
+      %W insert end [j:expand_filename $f]
+      %W xview end
+      focus %W				;# work around Tk4 "all" binding
+      break
     }
   }
   j:default_button .pr.b.ok .pr.mid.e
@@ -143,8 +133,7 @@ proc j:prompt { args } {
   update
   grab .pr
   tkwait window .pr
-  j:tk3 {focus $old_focus}
-  j:tk4 {focus -force $old_focus}	;# can't figure out a better way...
+  focus -force $old_focus	;# can't figure out a better way...
   if $doing_history {
     if {"x$j_prompt(result)" != "x$cancelvalue"} {
       j:history:append $history $j_prompt(result)
@@ -166,9 +155,60 @@ proc j:prompt_font { args } {
     {prompt "Font:"}
     {pattern "*"}
   }
-  # set prompt [j:ldb:text $prompt]	;# currently ignored
+  global j_prompt
   
-  return [exec xfontsel -pattern $pattern -print]
+  global jfont_size jfont_family jfont_bold jfont_italic
+  set jfont_size 12
+  set jfont_bold 0
+  set jfont_italic 0
+  
+  toplevel .pr
+  wm title .pr $prompt
+  wm withdraw .pr			;# lets us "update" without flashing
+  					;# will be undone by j:dialogue
+  message .pr.msg -width 300 -text $prompt -anchor w
+  frame .pr.mid
+  
+  j:option .pr.mid.fam -list [font families] -variable jfont_family -width 30
+  entry .pr.mid.size -width 5 -textvariable jfont_size
+  checkbutton .pr.mid.bold -text bold -variable jfont_bold
+  checkbutton .pr.mid.italic -text italic -variable jfont_italic
+  pack \
+    [j:filler .pr.mid] \
+    .pr.mid.fam \
+    .pr.mid.size \
+    .pr.mid.bold \
+    .pr.mid.italic \
+    [j:filler .pr.mid] \
+    -side left -fill x
+  
+  j:buttonbar .pr.b -default ok -buttons {
+    {ok OK
+      {
+        set j_prompt(result) [list $jfont_family $jfont_size]
+        if $jfont_bold {lappend j_prompt(result) bold}
+        if $jfont_italic {lappend j_prompt(result) italic}
+        destroy .pr
+      }
+    }
+  }
+  pack \
+    [j:filler .pr] \
+    .pr.msg \
+    -side top -padx 10 -fill x
+  pack \
+    [j:filler .pr] \
+    .pr.mid \
+    [j:filler .pr] \
+    [j:rule .pr] \
+    .pr.b \
+    -side top -fill x
+  focus .pr.mid.size
+  update
+  j:dialogue .pr
+  grab .pr
+  tkwait window .pr
+  return $j_prompt(result)
 }
 
 ######################################################################
@@ -491,17 +531,3 @@ proc j:prompt_colour_rgb:update_colour {w var value} {
 proc j:prompt_color_rgb \
   [info args j:prompt_colour_rgb] \
   [info body j:prompt_colour_rgb]
-
-
-
-
-
-
-
-
-
-
-
-
-
-
