@@ -1,7 +1,7 @@
 # jtextemacs.tcl - additional procedures for Emacs-like Text bindings
 #
 ######################################################################
-# Copyright 1992-1995 by Jay Sekora.  This file may be freely        #
+# Copyright 1992-1998 by Jay Sekora.  This file may be freely        #
 # distributed, modified or unmodified, for any purpose, provided     #
 # that this copyright notice is retained verbatim in all copies and  #
 # no attempt is made to obscure the authorship of this file.  If you #
@@ -10,6 +10,10 @@
 # your users with instructions for getting the original sources.     #
 ######################################################################
 
+catch {
+  package require jldb
+}
+
 # TO DO:
 # ^L
 # sentence-manipulation stuff
@@ -340,8 +344,8 @@ proc j:tkb:e:exchange_point_and_mark { W K A } {
     $W mark set emacs_mark insert
     j:tb:move $W $mark
   } else {
-    error [j:ldb textemacs:nomarkset \
-      "The mark is not set in text widget $W."]
+    error [subst [::jldb::long_text textemacs:nomarkset \
+      {The mark is not set in text widget $W.}]]
   }
 }
 
