@@ -1,7 +1,7 @@
 # jtexttags.tcl - tagged typing and tagging the selection for Text bindings
 #
 ######################################################################
-# Copyright 1992-1996 by Jay Sekora.  This file may be freely        #
+# Copyright 1992-1998 by Jay Sekora.  This file may be freely        #
 # distributed, modified or unmodified, for any purpose, provided     #
 # that this copyright notice is retained verbatim in all copies and  #
 # no attempt is made to obscure the authorship of this file.  If you #
@@ -10,6 +10,10 @@
 # your users with instructions for getting the original sources.     #
 ######################################################################
 
+catch {
+  package require jldb
+}
+
 # TO DO: clear_tags, clear_marks
 
 # see also j:text:insert in jtext.tcl
@@ -204,8 +208,8 @@ proc j:tag:clear_tag { w pattern } {
 
 proc j:tag:tag_text { w tag first last } {
   if [$w compare $first > $last] {
-    error [j:ldb texttags:first_gt_last \
-      "Text index \"first\" ($first) > \"last\" ($last)."]
+    error [subst [::jldb::long_text texttags:first_gt_last \
+      {Text index "first" ($first) > "last" ($last).}]]
   }
   
   set split_tag [split $tag ":"]
@@ -239,8 +243,8 @@ proc j:tag:tag_text { w tag first last } {
 
 proc j:tag:untag_text { w pattern first last } {
   if [$w compare $first > $last] {
-    error [j:ldb texttags:first_gt_last \
-      "Text index \"first\" ($first) > \"last\" ($last)."]
+    error [subst [::jldb::long_text texttags:first_gt_last \
+      {Text index "first" ($first) > "last" ($last).}]]
   }
   
   foreach possible_tag [$w tag names] {
@@ -479,7 +483,7 @@ proc j:tag:apply_annotation { args } {
   }
   
   if {[llength $args] < 2} {
-    error [j:ldb:text texttags:anno_args \
+    error [::jldb::long_text texttags:anno_args \
       "wrong # args: should be j:tag:apply_annotation ?options? widget state"]
   }
   
